# Notebook documents

The files contained in this directory are intended to provide a simple access to the basic features of `SPIKE`.

They provide a simple User Interface, in the popular Jupyter Notebook format.
Each Notebook provides a single set of functions, for instance 

- Processing and display of a 1D NMR dataset
- Processing and display of a 2D NMR dataset
- Processing and display of a DOSY dataset   (still in progress)
- Processing and display of a 1D FT-ICR-MS dataset  (still in progress)
- Display of a 2D FT-ICR-MS dataset  (still in progress)

*to come soon*

- Display and comparison of a set of 1D NMR datasets
- Processing and display of a 1D Orbitrap-MS dataset

This is still an early effort, and the number of *recipes* should grow rapidly - **SPIKE Users are welcome to provide their own !**

The Notebooks can be migrated anywhere, as long as spike is installed and available.
A typical usage is to copy a version close the data to be analysed, and to keep it there, as a lab-book, holding the analysis, and eventually your comments on the data.

*remarks*

*The notebooks are kept both as ` *.ipynb` (as reference) and as ` *.py` (to follow the difference between commit.) Both version are identical*


